@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: greet.c,v 1.21 2007/10/18 21:51:43 evertonm Exp $ */
+/* $Id: greet.c,v 1.22 2007/10/19 20:10:18 evertonm Exp $ */
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -107,10 +107,6 @@ int nepim_write_greetings(const nepim_greet_t *opt, char *buf, int buf_size)
 		GREET_PARTIAL_MINMAX,    opt->report_partial_min_max,
                 GREET_PASSWORD,          opt->password_buf);
 
-#if 1
-  fprintf(stderr, "DEBUG [%s]\n", buf);
-#endif
-
   if (pr < 1)
     return NEPIM_GREET_WRITE_IO;
   if (pr >= buf_size)
